#ifndef DS_H
#define DS_H

#include <QDateTime>
#include <QString>

namespace DS {
    enum portMode {
        undecidedPort, twoPort, onePort,
    };

    // NB: always maintain cableNames[] (in dataset.cpp) in sync!
    // The number in the comment represents the numerical value
    // as it is read through the serial protocol.
    enum cableType {
        // 0        1           2           3         4
        AIRCELL5, AIRCELL7, AIRCOMPLUS, ECOFLEX10, ECOFLEX15,
        // 5   6      7        8        9         10
        H155, H500, H1001, H2000FLEX, K02252D, MULFLEX141,
        // 11    12      13     14      15     16     17
        RG58CU, RG58U, RG59BU, RG142, RG174U, RG178, RG188,
        // 18      19       20       21      22      23
        RG196, RG213FOAM, RG213U, RG213UBX, RG214, RG214U,
        // 24   25      26     27      28     29     30
        RG223, RG316, RG316U, RG400, RG400U, RG402, RG405,
        // 31  32
        UT85, UT141,
        // Cannot be selected from the device UI but from the
        // Windows tool.
        UNDEFINED = 255
    };

    const int nDataPoints = 267;

    struct dataset {
        QDateTime tstamp;
        double ubat;
        enum portMode mode;
        long fstart, fstop;
        enum cableType ctype;
        int clength;       // in cm
        // These are the actual analyzer data.
        // r holds the real part of (complex) Z in oneport mode,
        // x holds the imaginary part.  In twoport mode, r holds
        // the attenuation value a, and x holds the phase delay
        // in degrees.
        double freq[nDataPoints];
        double r[nDataPoints];
        double x[nDataPoints];
    };

    enum dsException {
        openFailed,
        wrongFormat,
        syntaxError,
        invalidIndex,
    };


    // data shared with the serialThread instance
    struct sharedData {
        QString portName;
        enum cmd_t {
            cmdNop, cmdConnect, cmdFstart, cmdFstop,
            cmdMem, cmdCLength, cmdCType
        } cmd;
        qint32 cmdArg;
        enum childState_t {
            childInit,
            childFailed,
            childRunning,
            childDone
        } childState;
    };
}

#endif // DS_H
